@@ -1,4 +1,5 @@
-# (c) 2009-2018 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# -*- coding: utf-8 -*-
+# (c) 2009-2020 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
@@ -10,22 +11,23 @@ Two alternative lock storage classes are defined here: one in-memory
 
 See :class:`~wsgidav.lock_manager.LockManager`
 """
+from wsgidav import compat, util
+from wsgidav.lock_manager import (
+    generate_lock_token,
+    lock_string,
+    normalize_lock_root,
+    validate_lock,
+)
+from wsgidav.rw_lock import ReadWriteLock
+
 import os
 import shelve
 import time
 
-from wsgidav import compat, util
-from wsgidav.lock_manager import (
-    generateLockToken,
-    lockString,
-    normalizeLockRoot,
-    validateLock
-)
-from wsgidav.rw_lock import ReadWriteLock
 
 __docformat__ = "reStructuredText"
 
-_logger = util.getModuleLogger(__name__)
+_logger = util.get_module_logger(__name__)
 
 # TODO: comment's from Ian Bicking (2005)
 # @@: Use of shelve means this is only really useful in a threaded environment.
@@ -63,26 +65,31 @@ class LockStorageDict(object):
 
         { 'URL2TOKEN:/temp/litmus/lockme': ['opaquelocktoken:0x1d7b86...',
                                             'opaquelocktoken:0xd7d4c0...'],
-          'opaquelocktoken:0x1d7b86...': { 'depth': '0',
-                                           'owner': "<?xml version=\'1.0\' encoding=\'UTF-8\'?>\\n<owner xmlns="DAV:">litmus test suite</owner>\\n",
-                                           'principal': 'tester',
-                                           'root': '/temp/litmus/lockme',
-                                           'scope': 'shared',
-                                           'expire': 1261328382.4530001,
-                                           'token': 'opaquelocktoken:0x1d7b86...',
-                                           'type': 'write',
-                                           },
-          'opaquelocktoken:0xd7d4c0...': { 'depth': '0',
-                                           'owner': '<?xml version=\'1.0\' encoding=\'UTF-8\'?>\\n<owner xmlns="DAV:">litmus: notowner_sharedlock</owner>\\n',
-                                           'principal': 'tester',
-                                           'root': '/temp/litmus/lockme',
-                                           'scope': 'shared',
-                                           'expire': 1261328381.6040001,
-                                           'token': 'opaquelocktoken:0xd7d4c0...',
-                                           'type': 'write'
-                                           },
+          'opaquelocktoken:0x1d7b86...': {
+            'depth': '0',
+            'owner': "<?xml version=\'1.0\' encoding=\'UTF-8\'?>\\n<owner xmlns="DAV:">"
+                + "litmus test suite</owner>\\n",
+            'principal': 'tester',
+            'root': '/temp/litmus/lockme',
+            'scope': 'shared',
+            'expire': 1261328382.4530001,
+            'token': 'opaquelocktoken:0x1d7b86...',
+            'type': 'write',
+            },
+          'opaquelocktoken:0xd7d4c0...': {
+            'depth': '0',
+            'owner': '<?xml version=\'1.0\' encoding=\'UTF-8\'?>\\n<owner xmlns="DAV:">'
+                + 'litmus: notowner_sharedlock</owner>\\n',
+            'principal': 'tester',
+            'root': '/temp/litmus/lockme',
+            'scope': 'shared',
+            'expire': 1261328381.6040001,
+            'token': 'opaquelocktoken:0xd7d4c0...',
+            'type': 'write'
+           },
          }
     """  # noqa
+
     LOCK_TIME_OUT_DEFAULT = 604800  # 1 week, in seconds
     LOCK_TIME_OUT_MAX = 4 * 604800  # 1 month, in seconds
 
@@ -133,7 +140,7 @@ class LockStorageDict(object):
 
         Side effect: if lock is expired, it will be purged and None is returned.
         """
-        self._lock.acquireRead()
+        self._lock.acquire_read()
         try:
             lock = self._dict.get(token)
             if lock is None:
@@ -143,7 +150,9 @@ class LockStorageDict(object):
                 return None
             expire = float(lock["expire"])
             if expire >= 0 and expire < time.time():
-                _logger.debug("Lock timed-out({}): {}".format(expire, lockString(lock)))
+                _logger.debug(
+                    "Lock timed-out({}): {}".format(expire, lock_string(lock))
+                )
                 self.delete(token)
                 return None
             return lock
@@ -166,7 +175,7 @@ class LockStorageDict(object):
         - lock['timeout'] may be normalized and shorter than requested
         - lock['token'] is added
         """
-        self._lock.acquireWrite()
+        self._lock.acquire_write()
         try:
             # We expect only a lock definition, not an existing lock
             assert lock.get("token") is None
@@ -175,7 +184,7 @@ class LockStorageDict(object):
 
             # Normalize root: /foo/bar
             org_path = path
-            path = normalizeLockRoot(path)
+            path = normalize_lock_root(path)
             lock["root"] = path
 
             # Normalize timeout from ttl to expire-date
@@ -188,9 +197,9 @@ class LockStorageDict(object):
             lock["timeout"] = timeout
             lock["expire"] = time.time() + timeout
 
-            validateLock(lock)
+            validate_lock(lock)
 
-            token = generateLockToken()
+            token = generate_lock_token()
             lock["token"] = token
 
             # Store lock
@@ -207,7 +216,9 @@ class LockStorageDict(object):
                 tokList.append(token)
                 self._dict[key] = tokList
             self._flush()
-            _logger.debug("LockStorageDict.set({!r}): {}".format(org_path, lockString(lock)))
+            _logger.debug(
+                "LockStorageDict.set({!r}): {}".format(org_path, lock_string(lock))
+            )
             return lock
         finally:
             self._lock.release()
@@ -229,7 +240,7 @@ class LockStorageDict(object):
         if timeout < 0 or timeout > LockStorageDict.LOCK_TIME_OUT_MAX:
             timeout = LockStorageDict.LOCK_TIME_OUT_MAX
 
-        self._lock.acquireWrite()
+        self._lock.acquire_write()
         try:
             # Note: shelve dictionary returns copies, so we must reassign
             # values:
@@ -247,10 +258,10 @@ class LockStorageDict(object):
 
         Returns True on success. False, if token does not exist, or is expired.
         """
-        self._lock.acquireWrite()
+        self._lock.acquire_write()
         try:
             lock = self._dict.get(token)
-            _logger.debug("delete {}".format(lockString(lock)))
+            _logger.debug("delete {}".format(lock_string(lock)))
             if lock is None:
                 return False
             # Remove url to lock mapping
@@ -273,19 +284,19 @@ class LockStorageDict(object):
             self._lock.release()
         return True
 
-    def getLockList(self, path, includeRoot, includeChildren, tokenOnly):
+    def get_lock_list(self, path, include_root, include_children, token_only):
         """Return a list of direct locks for <path>.
 
         Expired locks are *not* returned (but may be purged).
 
         path:
             Normalized path (utf8 encoded string, no trailing '/')
-        includeRoot:
-            False: don't add <path> lock (only makes sense, when includeChildren
+        include_root:
+            False: don't add <path> lock (only makes sense, when include_children
             is True).
-        includeChildren:
+        include_children:
             True: Also check all sub-paths for existing locks.
-        tokenOnly:
+        token_only:
             True: only a list of token is returned. This may be implemented
             more efficiently by some providers.
         Returns:
@@ -293,31 +304,31 @@ class LockStorageDict(object):
         """
         assert compat.is_native(path)
         assert path and path.startswith("/")
-        assert includeRoot or includeChildren
+        assert include_root or include_children
 
         def __appendLocks(toklist):
             # Since we can do this quickly, we use self.get() even if
-            # tokenOnly is set, so expired locks are purged.
+            # token_only is set, so expired locks are purged.
             for token in toklist:
                 lock = self.get(token)
                 if lock:
-                    if tokenOnly:
+                    if token_only:
                         lockList.append(lock["token"])
                     else:
                         lockList.append(lock)
 
-        path = normalizeLockRoot(path)
-        self._lock.acquireRead()
+        path = normalize_lock_root(path)
+        self._lock.acquire_read()
         try:
             key = "URL2TOKEN:{}".format(path)
             tokList = self._dict.get(key, [])
             lockList = []
-            if includeRoot:
+            if include_root:
                 __appendLocks(tokList)
 
-            if includeChildren:
+            if include_children:
                 for u, ltoks in self._dict.items():
-                    if util.isChildUri(key, u):
+                    if util.is_child_uri(key, u):
                         __appendLocks(ltoks)
 
             return lockList
@@ -329,22 +340,23 @@ class LockStorageDict(object):
 # LockStorageShelve
 # ========================================================================
 
+
 class LockStorageShelve(LockStorageDict):
     """
     A low performance lock manager implementation using shelve.
     """
 
-    def __init__(self, storagePath):
+    def __init__(self, storage_path):
         super(LockStorageShelve, self).__init__()
-        self._storagePath = os.path.abspath(storagePath)
+        self._storage_path = os.path.abspath(storage_path)
 
     def __repr__(self):
-        return "LockStorageShelve({!r})".format(self._storagePath)
+        return "LockStorageShelve({!r})".format(self._storage_path)
 
     def _flush(self):
         """Write persistent dictionary to disc."""
         _logger.debug("_flush()")
-        self._lock.acquireWrite()  # TODO: read access is enough?
+        self._lock.acquire_write()  # TODO: read access is enough?
         try:
             self._dict.sync()
         finally:
@@ -352,7 +364,7 @@ class LockStorageShelve(LockStorageDict):
 
     def clear(self):
         """Delete all entries."""
-        self._lock.acquireWrite()  # TODO: read access is enough?
+        self._lock.acquire_write()  # TODO: read access is enough?
         try:
             was_closed = self._dict is None
             if was_closed:
@@ -366,17 +378,18 @@ class LockStorageShelve(LockStorageDict):
             self._lock.release()
 
     def open(self):
-        _logger.debug("open({!r})".format(self._storagePath))
+        _logger.debug("open({!r})".format(self._storage_path))
         # Open with writeback=False, which is faster, but we have to be
         # careful to re-assign values to _dict after modifying them
-        self._dict = shelve.open(self._storagePath, writeback=False)
-#        if __debug__ and self._verbose >= 2:
-#                self._check("After shelve.open()")
-#            self._dump("After shelve.open()")
+        self._dict = shelve.open(self._storage_path, writeback=False)
+
+    #        if __debug__ and self._verbose >= 2:
+    #                self._check("After shelve.open()")
+    #            self._dump("After shelve.open()")
 
     def close(self):
         _logger.debug("close()")
-        self._lock.acquireWrite()
+        self._lock.acquire_write()
         try:
             if self._dict is not None:
                 self._dict.close()
