@@ -1,34 +1,35 @@
-# (c) 2009-2018 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# -*- coding: utf-8 -*-
+# (c) 2009-2020 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 """
 Simple example how to a run WsgiDAV in a 3rd-party WSGI server.
 """
 from __future__ import print_function
-
 from tempfile import gettempdir
-
 from wsgidav import __version__
 from wsgidav.fs_dav_provider import FilesystemProvider
-from wsgidav.wsgidav_app import DEFAULT_CONFIG, WsgiDAVApp
+from wsgidav.wsgidav_app import WsgiDAVApp
+
 
 __docformat__ = "reStructuredText"
 
 
 def main():
-    rootpath = gettempdir()
-    provider = FilesystemProvider(rootpath)
+    root_path = gettempdir()
+    provider = FilesystemProvider(root_path)
 
-    config = DEFAULT_CONFIG.copy()
-    config.update({
+    config = {
         "provider_mapping": {"/": provider},
-        "user_mapping": {},
+        "http_authenticator": {
+            "domain_controller": None  # None: dc.simple_dc.SimpleDomainController(user_mapping)
+        },
+        "simple_dc": {"user_mapping": {"*": True}},  # anonymous access
         "verbose": 1,
         "enable_loggers": [],
-        "propsmanager": True,      # True: use property_manager.PropertyManager
-        "locksmanager": True,      # True: use lock_manager.LockManager
-        "domaincontroller": None,  # None: domain_controller.WsgiDAVDomainController(user_mapping)
-        })
+        "property_manager": True,  # True: use property_manager.PropertyManager
+        "lock_manager": True,  # True: use lock_manager.LockManager
+    }
     app = WsgiDAVApp(config)
 
     # For an example, use CherryPy
@@ -38,7 +39,7 @@ def main():
         bind_addr=(config["host"], config["port"]),
         wsgi_app=app,
         server_name="WsgiDAV/{} {}".format(__version__, CherryPyWSGIServer.version),
-        )
+    )
 
     try:
         server.start()
@@ -49,6 +50,8 @@ def main():
 
     # For an example, use paste.httpserver
     # (See http://pythonpaste.org/modules/httpserver.html for more options)
+
+
 #    from paste import httpserver
 #    httpserver.serve(app,
 #                     host="localhost",
